﻿--[[
    Copyright Daniel D. Neilson, 2006

    This file is part of DKPmon.

    DKPmon is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    DKPmon is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DKPmon; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
]]
--[[
    Functions for:
        - Parsing biditems console command
        - Adding items to the list of bidable items
        - Looking up the cost of an item
]]

local compost = AceLibrary("Compost-2.0")

--[[
    ParseItemLink(link)
    Description:
        Parses an item link for the item's colour and name
    Input:
        link: Item link of the item to be parsed.
    Output:
        colour, name
            colour = string, hex code of the item's colour
            name = string, name of the item without the '[' & ']'
]]
function DKPmon:ParseItemLink(link)
    local _,_,colour = string.find(link, "|c(.+)|Hitem")
    local _,_,name = string.find(link, "|h%[(.+)%]|h|")
    return colour,name
end

--[[
    DKPmon:ParseBidItems(item0, item1, ...)
    Description:
        Function to handle the biditem console command.
    Input:
        link: Item link of the item to be parsed.
    Output:
        colour, name
            colour = string, hex code of the item's colour
            name = string, name of the item without the '[' & ']'
]]
function DKPmon:ParseBidItems(item0, item1, item2, item3, item4, item5, item6)
    if self.bidding.bidstate ~= 0 then
        self:Print("Bidding is open, cannot add more items. Close bidding first.")
        return
    end
    local item = compost:AcquireHash(0, item0, 1, item1, 2, item2, 3, item3, 4, item4, 5, item5, 6, item6)

    local p = 0
    while item[p] ~= nil do
        --[[
        local s,i = "",0
        while i ~= string.len(item[p]) do
            s = s..string.sub(item[p],i,i).." "
            i = i + 1
        end
        self:Print(s)
        ]]
        local colour, name = self:ParseItemLink(item[p])
        if colour == nil or name == nil then
            self:Print("Could not parse item link: "..item[p])
        else
            local cost,pool = self:LookupItem(name)
            if cost == nil then
                self:Print(string.format("ERROR -- item |c%s[%s]|r Not found in database", colour, name)) -- "..colour.."["..name.."]|r Not found in database")
            else
                self:AddBidItemToList(item[p], name, colour, cost, pool)
            end
        end
        p = p + 1
    end
    compost:Reclaim(item)
end

--[[
    LookupItem(name)
    Description:
        Looks up the given item name in self.itemvalues and returns
        the point cost & pool number for the item
    Input:
        name: The name, without the surrounding square brackets, of
              the item to lookup.
    Output:
        cost, pool
            cost: The point-cost of the item
            pool: The pool the item is in.
        Note: returns nil if the item wasn't found.
]]
function DKPmon:LookupItem(name)
    local tab = self.itemvalues[name]
    if tab == nil then return; end
    return tab.value,tab.pool
end